tomlcheck
==========

.. image:: https://img.shields.io/pypi/v/tomlcheck.svg
    :target: https://pypi.org/project/tomlcheck
    :alt:

.. image:: https://img.shields.io/pypi/pyversions/tomlcheck.svg
    :target: https://pypi.org/project/tomlcheck
    :alt:

.. image:: https://travis-ci.com/sayanarijit/tomlcheck.svg?branch=master
    :target: https://travis-ci.com/sayanarijit/tomlcheck
    :alt:

.. image:: https://codecov.io/gh/sayanarijit/tomlcheck/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/sayanarijit/tomlcheck
    :alt:

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/python/black
    :alt:


A simple toml syntax checker


Installation
------------

.. code-block:: bash

    pip install -U tomlcheck


Usage
-----

.. code-block:: bash

    tomlcheck /path/to/file1.toml /path/to/file2.toml


Help Menu
---------

.. code-block:: bash

    tomlcheck --help
